@@ -55,7 +55,7 @@ For faster compile times (incremental compilation) it might make sense
 for a project to supply a permanent caching directory instead. If the specified
 directory does not exist, it'll be created automatically.
 
-Env var: `RUSTIMPORT_FORCE_REBUILD=<directory path>`
+Env var: `RUSTIMPORT_CACHE_DIR=<directory path>`
 """
 
 checksum_hasher = hashlib.sha1
@@ -65,4 +65,4 @@ constructors from `hashlib` (e.g. `hashlib.md5(...)`  or `hashlib.sha256(...)`).
 
 By default, sha1 is used as it has the [best performance](https://github.com/SharkyRawr/python-hashlib-benchmark)
 and is [reasonably collision-proof](https://crypto.stackexchange.com/a/2584).
-"""
\ No newline at end of file
+"""
